<?php
/**
 * @package Themetastico
 */

// Name of this theme
$themetastico_theme_name = 'Themetastico';

// Set the content width based on the theme's design and stylesheet
if ( ! isset( $content_width ) )
	$content_width = 640;

// Load translation
load_theme_textdomain( 'themetastico', TEMPLATEPATH . '/includes/languages' );

// run themetastico_setup() when the 'after_setup_theme' hook is run
add_action( 'after_setup_theme', 'themetastico_setup' );
if( !function_exists('themetastico_setup') ) {
	function themetastico_setup() {

		// Remove some junk from header	
		//remove_action('wp_head', 'rsd_link');
		//remove_action('wp_head', 'wlwmanifest_link');
		//remove_action('wp_head', 'feed_links_extra', 3);
		//remove_action('wp_head', 'index_rel_link');
		//remove_action('wp_head', 'start_post_rel_link', 10, 0);
		//remove_action('wp_head', 'parent_post_rel_link', 10, 0);
		//remove_action('wp_head', 'adjacent_posts_rel_link', 10, 0);

		// Add styles for the visual editor with "editor-style.css" to match the theme style.
		add_editor_style('css/editor-style.css');
	
		// Enable HTML markup in user profiles
		remove_filter('pre_user_description', 'wp_filter_kses');

		// Add support for post thumbnails
		add_theme_support('post-thumbnails');
	
		// Add default posts and comments RSS feed links to head
		add_theme_support('automatic-feed-links');
	
		// Add custom menus location
		register_nav_menus( array(
			'top_links' => __( 'Links in top', 'themetastico' ),
			'header_menu' => __( 'Header navigation', 'themetastico' ),
			'footer_menu' => __( 'Footer navigation', 'themetastico' )
		) );
	
		// Add support for custom background
		add_custom_background();

		// Add support for custom image header (%s = TEMPLATEURL)
		add_custom_image_header( 'themetastico_logo_style', 'themetastico_admin_logo_style');
		//define( 'HEADER_IMAGE', get_template_directory_uri() . '/images/logos/logo-1.jpg' );
		define( 'HEADER_IMAGE_WIDTH', 270 );
		define( 'HEADER_IMAGE_HEIGHT', 50 );	
		define( 'NO_HEADER_TEXT', true );
		define( 'HEADER_TEXTCOLOR', '' );
		register_default_headers( array(
			'logo1' => array(
				'url' => '%s/images/logos/logo-1.jpg',
				'thumbnail_url' => '%s/images/logos/logo-1-thumbnail.jpg',
				'description' => __( 'Logo 1', 'themetastico' )
			),
			'logo2' => array(
				'url' => '%s/images/logos/logo-2.jpg',
				'thumbnail_url' => '%s/images/logos/logo-2-thumbnail.jpg',
				'description' => __( 'Logo 2', 'themetastico' )
			),
		) );
		
		// Add some options with default values
		add_option('themetastico_which_css', 'right' );
		add_option('themetastico_show_sharing_buttons', true );
		add_option('themetastico_use_twitter', true );
		add_option('themetastico_use_facebook_like', true );
		add_option('themetastico_posts_per_slideshow', 3 );
		add_option('themetastico_use_lazy_load', true );
		add_option('themetastico_feedburner_count', '0' );
		add_option('themetastico_feedburner_lastcheck', 1 );
		
	}
}

// Load Functions and Classes
require_once( TEMPLATEPATH . '/includes/settings.php' );
require_once( TEMPLATEPATH . '/includes/widgets.php' );
require_once( TEMPLATEPATH . '/includes/head.php' );
require_once( TEMPLATEPATH . '/includes/comments.php' );
require_once( TEMPLATEPATH . '/includes/content.php' );
require_once( TEMPLATEPATH . '/includes/sharing.php' );
require_once( TEMPLATEPATH . '/includes/pagination.php' );

// Improve search form
function themetastico_search_form( $form ) {

	$query = get_search_query() != '' ? get_search_query() : __('Search', 'themetastico');
    $form = '
    <form class="blog-search" method="get" action="' . site_url() . '">
		<input name="s" type="text" class="text" value="' . $query . '" />
		<input type="submit" class="button" value="'. esc_attr__('Search', 'themetastico') .'" />
    </form>';

    return $form;
}
add_filter( 'get_search_form', 'themetastico_search_form' );

// Add a link to admin footer
add_filter('admin_footer_text', 'themetastico_admin_footer');
function themetastico_admin_footer() {
	global $themetastico_theme_name;
	echo '<a href="http://techtastico.com/themes/" target="_blank">'.sprintf(__('You are using %s WordPress Theme', 'themetastico'), $themetastico_theme_name).'</a>';
}

// Produces a list of pages without whitespace for horizontal menu
function themetastico_pages_menu( $args ) {
	$class = $args['menu_class'];
	$depth = $args['depth'];
	$menuitems = str_replace( array( "\r", "\n", "\t" ), '', wp_list_pages('title_li=&sort_column=menu_order&echo=0&depth='.$depth) );
	$menu = '<ul class="'.$class.'">';	
	$current_page_item = (is_front_page() || is_home()) ? ' current_page_item' : '';
	$menu .= '<li class="home_item' . $current_page_item . '"><a href="' . site_url() .'/" title="' . get_bloginfo('name') . '">' . __('Home', 'themetastico') . '</a></li> ';
	$menu .= $menuitems;
	$menu .= '</ul>';
	echo $menu;
}

// Produces a list of pages without whitespace for navigation menu
function themetastico_pages_nav_menu( $args ) {
	$class = $args['menu_class'];
	$depth = $args['depth'];
	$menu = '<ul class="'.$class.'">';	
	$current_page_item = (is_front_page() || is_home()) ? ' current_page_item' : '';
	$menu .= '<li class="home_item' . $current_page_item . '"><a href="' . site_url() .'/" title="' . get_bloginfo('name') . '">' . __('Home', 'themetastico') . '</a></li> ';
	$menu .= '</ul>';
	echo $menu;
}

// Action to call "pre_footer" hook
function pre_footer() {
	do_action('pre_footer');
}

?>