<?php
/**
 * @package Themetastico
 */

// Function to filter the default gallery shortcode
add_filter( 'post_gallery', 'themetastico_gallery' );
function themetastico_gallery($attr) {
	global $post, $wp_locale;

	static $instance = 0;
	$instance++;

	if( isset( $attr['orderby'] ) ) {
		$attr['orderby'] = sanitize_sql_orderby( $attr['orderby'] );
		if( !$attr['orderby'] )
			unset( $attr['orderby'] );
	}

	extract(shortcode_atts(array(
		'order'      => 'ASC',
		'orderby'    => 'menu_order ID',
		'id'         => $post->ID,
		'itemtag'    => 'dl',
		'icontag'    => 'dt',
		'captiontag' => 'dd',
		'columns'    => 3,
		'size'       => 'thumbnail',
		'include'    => '',
		'exclude'    => ''
	), $attr));

	$id = intval($id);
	if( 'RAND' == $order )
		$orderby = 'none';

	if( !empty($include) ) {
		$include = preg_replace( '/[^0-9,]+/', '', $include );
		$_attachments = get_posts( array('include' => $include, 'post_status' => 'inherit', 'post_type' => 'attachment', 'post_mime_type' => 'image', 'order' => $order, 'orderby' => $orderby) );

		$attachments = array();
		foreach ( $_attachments as $key => $val ) {
			$attachments[$val->ID] = $_attachments[$key];
		}
	} elseif( !empty($exclude) ) {
		$exclude = preg_replace( '/[^0-9,]+/', '', $exclude );
		$attachments = get_children( array('post_parent' => $id, 'exclude' => $exclude, 'post_status' => 'inherit', 'post_type' => 'attachment', 'post_mime_type' => 'image', 'order' => $order, 'orderby' => $orderby) );
	} else {
		$attachments = get_children( array('post_parent' => $id, 'post_status' => 'inherit', 'post_type' => 'attachment', 'post_mime_type' => 'image', 'order' => $order, 'orderby' => $orderby) );
	}

	if( empty($attachments) )
		return '';

	if( is_feed() ) {
		$output = "\n";
		foreach ( $attachments as $att_id => $attachment )
			$output .= wp_get_attachment_link($att_id, $size, true) . "\n";
		return $output;
	}

	$itemtag = tag_escape($itemtag);
	$captiontag = tag_escape($captiontag);
	$columns = intval($columns);
	$itemwidth = $columns > 0 ? floor(100/$columns) : 100;
	$float = is_rtl() ? 'right' : 'left';

	$selector = "gallery-{$instance}";

	$output = apply_filters( 'gallery_style', "\n" . '<div id="'.$selector.'" class="gallery galleryid-'.$id.'">' . "\n\t\t\t", 9 ); // Available filter: gallery_style

	$i = 0;
	foreach ( $attachments as $id => $attachment ) {
		$link = isset($attr['link']) && 'file' == $attr['link'] ? wp_get_attachment_link($id, $size, false, false) : wp_get_attachment_link($id, $size, true, false);

		$output .= "<{$itemtag} class='gallery-item'>";
		$output .= "
			<{$icontag} class='gallery-icon'>
				$link
			</{$icontag}>";
		if( $captiontag && trim($attachment->post_excerpt) ) {
			$output .= "
				<{$captiontag} class='gallery-caption'>
				" . wptexturize($attachment->post_excerpt) . "
				</{$captiontag}>";
		}
		$output .= "</{$itemtag}>";
		if( $columns > 0 && ++$i % $columns == 0 )
			$output .= '<br />';
	}

	$output .= "
			<br style='clear: both;' />
		</div>\n";

	return $output;
}

// Improve the_excerpt() function
remove_filter('get_the_excerpt', 'wp_trim_excerpt');
add_filter('get_the_excerpt', 'themetastico_trim_excerpt');
function  themetastico_trim_excerpt($text) {
	$raw_excerpt = $text;
	if( '' == $text ) {
		$text = get_the_content('');

		$text = strip_shortcodes( $text );

		$text = apply_filters('the_content', $text);
		$text = str_replace(']]>', ']]&gt;', $text);
		$text = preg_replace('@<script[^>]*?>.*?</script>@si', '', $text);
		$text = strip_tags($text);
		$excerpt_length = apply_filters('excerpt_length', 40);
		$excerpt_more = apply_filters('excerpt_more', ' ' . '...');
		$words = explode(' ', $text, $excerpt_length + 1);
		if(count($words) > $excerpt_length) {
			array_pop($words);
			$text = implode(' ', $words);
			$text = $text . $excerpt_more;
		}
	}
	return apply_filters('wp_trim_excerpt', $text, $raw_excerpt);
}

// Display post image with backward compatibility
function themetastico_post_thumbnail($always = false, $get_size = 'thumbnail') {
	global $post;
	
	if( $always || ( themetastico_show_summary() && is_home() ) || is_archive() || is_search() ) {
		$url = get_permalink();
		$title = the_title_attribute('echo=0');
		if( $get_size == 'thumbnail' ) {
			$width = get_option('thumbnail_size_w');
			$height = get_option('thumbnail_size_h');
			$src = themetastico_get_post_thumbnail_src('thumbnail');
		} elseif( $get_size == 'medium' ) {
			$width = get_option('medium_size_w');
			$height = get_option('medium_size_h');
			$src = themetastico_get_post_thumbnail_src('medium');
		} else {
			$width = get_option('large_size_w');
			$height = get_option('large_size_h');
			$src = themetastico_get_post_thumbnail_src('large');
		}
	
		if($src) {
			echo '<a href="'.$url.'" title="'.$title.'" class="thumbnail-link">';
			echo '<img width="'.$width.'" height="'.$height.'" src="'.$src.'" class="thumbnail wp-post-image" alt="'.$title.'" />';
			echo '</a>';
		} else {
			return false;
		}
	}
}

// Gets URL for post thumbnail
function themetastico_get_post_thumbnail_src($size = 'thumbnail') {
	global $post;
	
	if( has_post_thumbnail() ) {
		$image = wp_get_attachment_image_src( get_post_thumbnail_id(), $size );
	} else {
		$attachments = get_children( array( 'post_parent' => $post->ID, 'post_status' => 'inherit', 'post_type' => 'attachment', 'post_mime_type' => 'image', 'order' => 'ASC', 'orderby' => 'menu_order ID' ) );
	
		if( empty( $attachments ) )
			return false;
	
		foreach ( $attachments as $image_id => $attachment ) {
			$image = wp_get_attachment_image_src( $image_id, $size );
			break;
		}
	}

	return $image[0];
}

// For excerpts in home and archives
function themetastico_showexcerpt_class($classes) {

	if( ( themetastico_show_summary() && is_home() ) || is_archive() || is_search() ) {
		$classes[] = 'showexcerpt';
	}
		$classes[] = 'entry';
	
	return $classes;
}
add_filter('post_class', 'themetastico_showexcerpt_class');

// For excerpts in home and archives
function themetastico_which_css_class($classes) {

	$classes[] = 'layout-'.themetastico_which_css();
	
	return $classes;
}
add_filter('body_class', 'themetastico_which_css_class');

?>