<?php
/**
 * @package Themetastico
 */

// Improve wp_title() function
add_filter('wp_title', 'themetastico_wp_title', 1);
function themetastico_wp_title($title) {
	global $page, $paged, $cpage;

	if( $title != '' ) {
		if( is_404() ) {
			$title = sprintf( __( 'Page not found, Error 404 - %s', 'themetastico' ), esc_html(get_bloginfo('name'),1) );
		} elseif( is_search() ) {
			$title = get_search_query();
		}
	} elseif( is_feed() ) {
		$title = ' - ' . esc_html(get_bloginfo('description'),1);
	} else {
		$title = esc_html(get_bloginfo('name'),1). ' - ' . esc_html(get_bloginfo('description'),1);		
	}

	// Add a page number if necessary:
	$page_number = '';
	if ( $paged >= 2 || $page >= 2 || $cpage >= 2 ) {
		$page_number = ' ' . sprintf( __( '(Page %s)', 'themetastico' ), max( $paged, $page, $cpage ) );
	}
	
	$sufix = '';
	if( is_archive() ) {
		$sufix = ' - ' . esc_html(get_bloginfo('name'),1);
	}

	return $title.$sufix.$page_number;
}

// Include Javascript
add_action( 'get_header', 'themetastico_enqueue_javascript' );
function themetastico_enqueue_javascript(){
	// Include jQuery script in theme
	wp_deregister_script('jquery');
	if( themetastico_use_lazy_load() ) {
		// include jQuery with lazy load plugin
		wp_register_script('jquery', get_template_directory_uri().'/js/jquery.min.lazyload.js');
	} else {
		// include only jQuery without plugins
		wp_register_script('jquery', get_template_directory_uri().'/js/jquery.min.js'); 
	} 
	wp_enqueue_script('jquery');
	if( is_home() && !is_paged() && themetastico_show_slideshow() ) {
		wp_register_script('home_scripts', get_template_directory_uri().'/js/home.slideshow.js'); 
		wp_enqueue_script('home_scripts');
	}
	if( is_singular() && comments_open() && get_option('thread_comments') ) {
		wp_enqueue_script( 'comment-reply' );		
	}
	if( is_singular() && comments_open() ) {
		wp_register_script('singular_scripts', get_template_directory_uri().'/js/singular.js'); 
		wp_enqueue_script('singular_scripts');
	}
	if( themetastico_show_sharing_buttons() && themetastico_use_twitter() ) {
		wp_register_script('twitter_scripts', 'http://platform.twitter.com/widgets.js'); 
		wp_enqueue_script('twitter_scripts');
	}
	if( themetastico_show_sharing_buttons() && themetastico_use_facebook_share() ) {
		wp_register_script('fb_share_scripts', 'http://static.ak.fbcdn.net/connect.php/js/FB.Share'); 
		wp_enqueue_script('fb_share_scripts');
	}
	if( themetastico_show_sharing_buttons() && themetastico_use_buzz() ) {
		wp_register_script('buzz_scripts', 'http://www.google.com/buzz/api/button.js'); 
		wp_enqueue_script('buzz_scripts');
	}

}

// Javascript inside <header> and </header>
add_action('wp_head', 'themetastico_header_javascript');
function themetastico_header_javascript() {
?><script type="text/javascript">
/*<![CDATA[*/
$(document).ready(function(){
	<?php /* start lazy load */ if( themetastico_use_lazy_load() ) : ?>$("div.post img, div#comments img").lazyload({placeholder:"<?php echo get_template_directory_uri(); ?>/images/trans.gif",effect:"fadeIn"});<?php endif; /* end lazy load */ ?>
	
	var searchboxtoptext=$(".blog-search .text");
	searchboxtoptext.blur(function(){if(searchboxtoptext.val()=='')searchboxtoptext.val('<?php _e('Search', 'themetastico'); ?>');});
	searchboxtoptext.focus(function(){if(searchboxtoptext.val()=='<?php _e('Search', 'themetastico'); ?>')searchboxtoptext.val('');});
});
/*]]>*/
</script>
<?php if( themetastico_show_sharing_buttons() && themetastico_use_plus1() ) { ?><script type="text/javascript" src="http://apis.google.com/js/plusone.js">
	{lang: 'es-419'}
</script>
<?php 
	}
}

// Secure the Blog by removing version info from head and feeds
add_filter('the_generator', 'themetastico_remove_version');
function themetastico_remove_version() {
	return '';
}

// Change feed links
add_filter('feed_link', 'themetastico_custom_feed_link', 1, 2);
function themetastico_custom_feed_link($output, $feed) {
	
	if( strpos($output, 'comments') && themetastico_custom_comments_rss_url() ) {
		$output = themetastico_custom_comments_rss_url();
	} elseif( themetastico_custom_rss_url() ) {
		$output = themetastico_custom_rss_url();
	}

	return $output;
}

// Add Favicon
add_action('wp_head', 'themetastico_add_favicon', 1);
function themetastico_add_favicon() {

	echo '<link rel="shortcut icon" href="'.themetastico_favicon_url().'" type="image/x-icon" />'."\n";

}


// Add custom logo
function themetastico_logo_style() {
	if( get_header_image() ) {
?>
<style type="text/css">
#logo {
	width: <?php echo HEADER_IMAGE_WIDTH; ?>px; 
	height: <?php echo HEADER_IMAGE_HEIGHT; ?>px; 
}
#logo a {
	display: block;
	width: <?php echo HEADER_IMAGE_WIDTH; ?>px;
	height: <?php echo HEADER_IMAGE_HEIGHT; ?>px;
	text-indent: -9999px;
	background: transparent url(<?php header_image(); ?>) 0 0 no-repeat;
}
</style>
<?php
	}
}

// Add custom logo in admin preview
function themetastico_admin_logo_style() {
	if(
	 get_header_image() ) {
	?>
	<style type="text/css">
		#headimg {
			width: <?php echo HEADER_IMAGE_WIDTH; ?>px;
			height: <?php echo HEADER_IMAGE_HEIGHT; ?>px;
			background: transparent url(<?php header_image(); ?>) 0 0 no-repeat;
		}
	</style>
	<?php
	}
}

?>